==> Slicer3-3.0.2007-12-21-darwin-x86.tar.gz: Slicer3-3.0.2007-12-21-darwin-x86/lib/vtk-5.0/VTKLibraryDepends.cmake <==
SET(vtkCommon_LIB_DEPENDS "vtksys;-framework AppKit;-lpthread;-lm;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;/Users/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.dylib;m;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkFilteringTCL_LIB_DEPENDS "vtkFiltering;vtkCommonTCL;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkImagingTCL_LIB_DEPENDS "vtkImaging;vtkFilteringTCL;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphicsTCL_LIB_DEPENDS "vtkGraphics;vtkFilteringTCL;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkGenericFilteringTCL_LIB_DEPENDS "vtkGenericFiltering;vtkFilteringTCL;vtkGraphicsTCL;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;vtkpng;vtkzlib;vtkjpeg;vtktiff;vtkexpat;")
SET(vtkIOTCL_LIB_DEPENDS "vtkIO;vtkFilteringTCL;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;vtkfreetype;-lGL;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;")
SET(vtkRenderingTCL_LIB_DEPENDS "vtkRendering;vtkGraphicsTCL;vtkImagingTCL;/Users/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtk8.4.dylib;/Users/hayes/Slicer3-release-gbt/Slicer3/../Slicer3-lib/tcl-build/lib/libtcl8.4.dylib;m;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkVolumeRenderingTCL_LIB_DEPENDS "vtkVolumeRendering;vtkRenderingTCL;vtkIOTCL;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkHybridTCL_LIB_DEPENDS "vtkHybrid;vtkRenderingTCL;vtkIOTCL;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkWidgetsTCL_LIB_DEPENDS "vtkWidgets;vtkRenderingTCL;vtkHybridTCL;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkzlib_LIB_DEPENDS "")
SET(vtkjpeg_LIB_DEPENDS "")
SET(vtkpng_LIB_DEPENDS "vtkzlib;")
SET(vtktiff_LIB_DEPENDS "vtkzlib;vtkjpeg;")
SET(vtkexpat_LIB_DEPENDS "")
SET(vtkfreetype_LIB_DEPENDS "-framework AppKit;")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "-framework OpenGL;/usr/X11R6/lib/libGL.dylib;vtkfreetype;")

==> Slicer3-3.0.2008-01-17-darwin-x86.tar.gz: Slicer3-3.0.2008-01-17-darwin-x86/lib/vtk-5.0/VTKLibraryDepends.cmake <==
SET(vtkCommon_LIB_DEPENDS "vtksys;-framework AppKit;-lpthread;-lm;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;/Users/hayes/Slicer-3-0-release/Slicer-3-0/../Slicer3-lib/tcl-build/lib/libtcl8.4.dylib;m;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkFilteringTCL_LIB_DEPENDS "vtkFiltering;vtkCommonTCL;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkImagingTCL_LIB_DEPENDS "vtkImaging;vtkFilteringTCL;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphicsTCL_LIB_DEPENDS "vtkGraphics;vtkFilteringTCL;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkGenericFilteringTCL_LIB_DEPENDS "vtkGenericFiltering;vtkFilteringTCL;vtkGraphicsTCL;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;vtkpng;vtkzlib;vtkjpeg;vtktiff;vtkexpat;")
SET(vtkIOTCL_LIB_DEPENDS "vtkIO;vtkFilteringTCL;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;vtkfreetype;-lGL;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;/usr/X11R6/lib/libX11.dylib;/usr/X11R6/lib/libXext.dylib;")
SET(vtkRenderingTCL_LIB_DEPENDS "vtkRendering;vtkGraphicsTCL;vtkImagingTCL;/Users/hayes/Slicer-3-0-release/Slicer-3-0/../Slicer3-lib/tcl-build/lib/libtk8.4.dylib;/Users/hayes/Slicer-3-0-release/Slicer-3-0/../Slicer3-lib/tcl-build/lib/libtcl8.4.dylib;m;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkVolumeRenderingTCL_LIB_DEPENDS "vtkVolumeRendering;vtkRenderingTCL;vtkIOTCL;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkHybridTCL_LIB_DEPENDS "vtkHybrid;vtkRenderingTCL;vtkIOTCL;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkWidgetsTCL_LIB_DEPENDS "vtkWidgets;vtkRenderingTCL;vtkHybridTCL;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkzlib_LIB_DEPENDS "")
SET(vtkjpeg_LIB_DEPENDS "")
SET(vtkpng_LIB_DEPENDS "vtkzlib;")
SET(vtktiff_LIB_DEPENDS "vtkzlib;vtkjpeg;")
SET(vtkexpat_LIB_DEPENDS "")
SET(vtkfreetype_LIB_DEPENDS "-framework AppKit;")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "-framework OpenGL;/usr/X11R6/lib/libGL.dylib;vtkfreetype;")
